@@ -8,22 +8,32 @@
 #include <AppKit/NSColor.h>
 
 @implementation GormGuidelinePref
+
 - (id) init
 {
   if((self = [super init]) != nil)
     {
       NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
       int spacing = [defaults integerForKey: @"GuideSpacing"];
-      
+      NSColor *aColor = colorFromDict([defaults objectForKey: @"GuideColor"]);
+
+      // default the color to something, if nothing is returned.
+      if(aColor == nil)
+	{
+	  aColor = [NSColor redColor];
+	}
+
       if ( [NSBundle loadNibNamed:@"GormPrefGuideline" owner:self] == NO )
 	{
 	  NSLog(@"Can not load bundle GormPrefGuideline");
 	  return nil;
 	} 
 
+      [colorWell setColor: aColor];
       [spacingSlider setIntValue: spacing];
       [currentSpacing setIntValue: spacing];
       [halfSpacing setIntValue: spacing/2];
+
       _view =  [[window contentView] retain];
     }
   return self;
@@ -35,7 +45,6 @@
   [super dealloc];
 }
 
-
 -(NSView *) view
 {
   return _view;
@@ -47,15 +56,27 @@
   if(sender == spacingSlider)
     {
       int spacing = [spacingSlider intValue]; 
+
       [currentSpacing setIntValue: spacing];
       [halfSpacing setIntValue: spacing/2];
-      [defaults setInteger: spacing forKey: @"GuideSpacing"];
+      [defaults setInteger: spacing 
+		    forKey: @"GuideSpacing"];
+    }
+  else if(sender == colorWell)
+    {
+      NSColor *color = [colorWell color];
+      [defaults setObject: colorToDict(color) 
+		   forKey: @"GuideColor"];
     }
 }
 
 - (void) reset: (id)sender
 {
   [spacingSlider setIntValue: 10];
+  [colorWell setColor: [NSColor redColor]];
+
   [self ok: spacingSlider];
+  [self ok: colorWell];
 }
+
 @end
