@@ -33,6 +33,7 @@
 */
 
 #include "GormMenuAttributesInspector.h"
+#include "GormNSMenu.h"
 
 #include <Foundation/NSNotification.h>
 
@@ -44,9 +45,10 @@
 #include <AppKit/NSTextField.h>
 
 
-#define WINDOWSMENUTAG  0
-#define SERVICESMENUTAG 1 
-#define NORMALMENUTAG   2
+#define WINDOWSMENUTAG         0
+#define SERVICESMENUTAG        1 
+#define RECENTDOCUMENTSMENUTAG 2
+#define NORMALMENUTAG          3
 
 @implementation GormMenuAttributesInspector
 
@@ -89,12 +91,16 @@
 	  [doc setWindowsMenu:object];
 	  if ( [doc servicesMenu] == object ) 
 	    [doc setServicesMenu: nil];
+	  else if ( [doc recentDocumentsMenu] == object )	  
+	    [doc setRecentDocumentsMenu: nil];
 	  break;
 	  
 	case SERVICESMENUTAG:
 	  [doc setServicesMenu: object];	  
 	  if ( [doc windowsMenu] == object )	  
 	    [doc setWindowsMenu: nil];
+	  else if ( [doc recentDocumentsMenu] == object )	  
+	    [doc setRecentDocumentsMenu: nil];
 	  break;
 	  
 	case NORMALMENUTAG:
@@ -103,6 +109,14 @@
 	  if ( [doc servicesMenu] == object )
 	    [doc setServicesMenu: nil];
 	  break;
+	  
+	case RECENTDOCUMENTSMENUTAG: 
+	  [doc setRecentDocumentsMenu:object];
+	  if ( [doc servicesMenu] == object ) 
+	    [doc setServicesMenu: nil];
+	  else if ( [doc windowsMenu] == object )	  
+	    [doc setWindowsMenu: nil];
+	  break;
 	}
     }
 
@@ -121,7 +135,7 @@
   doc = (GormDocument *)[(id<IB>)NSApp activeDocument];
 
   [titleText setStringValue: [object title]];
-  [autoenable setState: ([object autoenablesItems]?NSOnState:NSOffState)];
+  [autoenable setState: ([object realAutoenablesItems]?NSOnState:NSOffState)];
 
   // set up the menu type matrix...
   if([doc windowsMenu] == object)
@@ -132,6 +146,10 @@
     {
       [menuType selectCellAtRow:SERVICESMENUTAG column: 0];
     }
+  else if([doc recentDocumentsMenu] == object)
+    {
+      [menuType selectCellAtRow:RECENTDOCUMENTSMENUTAG column: 0];
+    } 
   else 
     {
       [menuType selectCellAtRow:NORMALMENUTAG column: 0];
@@ -142,7 +160,9 @@
 /* delegate method used for menu title */
 - (void)controlTextDidChange:(NSNotification *)aNotification
 {
+  GormDocument *doc = (GormDocument *)[(id<IB>)NSApp activeDocument];
   [object setTitle: [titleText stringValue]];
+  [doc touch];
 }
 
 @end
