@@ -1,7 +1,7 @@
 /*
   GormBrowserAttributesInspector.m
 
-   Copyright (C) 2001-2005 Free Software Foundation, Inc.
+   Copyright (C) 2001-2015 Free Software Foundation, Inc.
 
    Author:  Adam Fedor <fedor@gnu.org>
             Laurent Julliard <laurent@julliard-online.org>
@@ -121,11 +121,11 @@
   [[tagForm cellAtIndex:0] setIntValue: [object tag]];
 
   [minColumnWidthField setStringValue:
-			 [NSString stringWithFormat:@"%i",
+			 [NSString stringWithFormat:@"%f",
 				   [object minColumnWidth]]];
   [maxVisibleColumnsField setStringValue:
-			    [NSString stringWithFormat:@"%i",
-				      [object maxVisibleColumns]]];
+			    [NSString stringWithFormat:@"%ld",
+				      (long int)[object maxVisibleColumns]]];
 
   [super revert:sender];
 }
