@@ -363,7 +363,7 @@ static NSText *_textObject;
   NSTableColumn *tc;
   NSRect drawingRect;
 
-  int columnIndex = [th columnAtPoint: 
+  NSUInteger columnIndex = [th columnAtPoint: 
 			  [th convertPoint:[theEvent locationInWindow]
 			      fromView: nil]];
   
@@ -413,12 +413,12 @@ static NSText *_textObject;
   RELEASE(_editedCell);
 }
 
-- (unsigned) draggingEntered: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingEntered: (id<NSDraggingInfo>)sender
 {
   return [self draggingUpdated: sender];
 }
 
-- (unsigned) draggingUpdated: (id<NSDraggingInfo>)sender
+- (NSDragOperation) draggingUpdated: (id<NSDraggingInfo>)sender
 {
   NSPasteboard	*dragPb;
   NSArray	*types;
