@@ -80,7 +80,10 @@ extern NSArray *predefinedNumberFormats;
   NSString *minValue, *maxValue;
   NSCell   *cell = [object cell];
   NSNumberFormatter *fmtr = [cell formatter];
-    
+
+  // Mark as changed...
+  [[(id<IB>)NSApp activeDocument] touch];
+
   if (sender == detachButton)
     { 
       [cell setFormatter: nil];
@@ -113,7 +116,7 @@ extern NSArray *predefinedNumberFormats;
          }
       else if (sender == formatForm)
         {
-          int idx;
+          NSUInteger idx;
           
           positiveFmt = [[sender cellAtIndex:0] stringValue];
           zeroFmt = [[sender cellAtIndex:1] stringValue];
@@ -134,7 +137,7 @@ extern NSArray *predefinedNumberFormats;
           else
             {
               [formatTable selectRow:idx byExtendingSelection:NO];
-              NSDebugLog(@"format found at index: %d", idx);
+              NSDebugLog(@"format found at index: %d", (int)idx);
             }
 
           // Update Appearance samples
@@ -181,7 +184,7 @@ extern NSArray *predefinedNumberFormats;
 
 - (void) revert: (id)sender
 {
-  int idx;
+  NSUInteger idx;
   NSNumberFormatter *fmtr = [[object cell] formatter];
 
   // Format form
@@ -226,14 +229,14 @@ extern NSArray *predefinedNumberFormats;
 
 /* Positive/Negative Format table data source */
 
-- (int)numberOfRowsInTableView:(NSTableView *)aTableView
+- (NSInteger)numberOfRowsInTableView:(NSTableView *)aTableView
 {
   return [NSNumberFormatter formatCount];
 }
 
 - (id)tableView:(NSTableView *)aTableView
   objectValueForTableColumn:(NSTableColumn *)aTableColumn
-  row:(int)rowIndex
+  row:(NSInteger)rowIndex
 {  
   if ( [[aTableColumn identifier] isEqualToString: @"positive"] )
     {
@@ -263,7 +266,7 @@ extern NSArray *predefinedNumberFormats;
 }
 
 - (void)tableView:(NSTableView *)aTableView willDisplayCell:(id)aCell
-   forTableColumn:(NSTableColumn*)aTableColumn row:(int)rowIndex
+   forTableColumn:(NSTableColumn*)aTableColumn row:(NSInteger)rowIndex
 {
   NSNumberFormatter *fmtr;
   
